@@ -153,26 +153,31 @@ RS_XML_SubstituteEntitiesDefault(USER_OBJECT_ replaceEntities)
 
 static R_CallMethodDef callMethods[] = {
 	ENTRY(RS_XML_RecursiveApply, 3),
+#ifdef UNUSED_DOT_CALLS
 	ENTRY(RS_XML_HtmlParseTree, 7),
+        ENTRY(RS_XML_setDoc, 2),
+        ENTRY(R_xmlNsAsCharacter, 1),
+	ENTRY(R_addXMLNodeFinalizer, 1),
+#endif
 	ENTRY(RS_XML_getDTD, 5),
 	ENTRY(RS_XML_libxmlVersion, 0),
-	ENTRY(RS_XML_Parse, 16),
-	ENTRY(RS_XML_ParseTree, 18),
-	ENTRY(R_newXMLDtd, 4),
+	ENTRY(RS_XML_Parse, 17),
+	ENTRY(RS_XML_ParseTree, 19),
+	ENTRY(R_newXMLDtd, 5),
 	ENTRY(R_newXMLDoc, 2),
 	ENTRY(R_newXMLNode, 6),
-	ENTRY(R_newXMLTextNode, 2),
-	ENTRY(R_xmlNewComment, 2),
-	ENTRY(R_newXMLCDataNode, 2),
-	ENTRY(R_newXMLPINode, 3),
+	ENTRY(R_newXMLTextNode, 3),
+	ENTRY(R_xmlNewComment, 3),
+	ENTRY(R_newXMLCDataNode, 3),
+	ENTRY(R_newXMLPINode, 4),
 	ENTRY(R_xmlNewNs, 3),
 	ENTRY(R_xmlSetNs, 3),
+	ENTRY(R_xmlRootNode, 3),
 	ENTRY(R_insertXMLNode, 4),
 	ENTRY(R_saveXMLDOM, 6),
 	ENTRY(R_xmlCatalogResolve, 3),
 	ENTRY(RS_XML_xmlNodeNumChildren, 1),
-        ENTRY(RS_XML_unsetDoc, 3),
-        ENTRY(RS_XML_setDoc, 2),
+        ENTRY(RS_XML_unsetDoc, 4),
         ENTRY(RS_XML_printXMLNode, 5),
         ENTRY(RS_XML_dumpHTMLDoc, 4),
         ENTRY(RS_XML_removeChildren, 3),
@@ -181,14 +186,13 @@ static R_CallMethodDef callMethods[] = {
         ENTRY(RS_XML_removeNodeAttributes, 3),
         ENTRY(RS_XML_getNsList, 2),
         ENTRY(RS_XML_setNodeName, 2),
-        ENTRY(R_xmlNsAsCharacter, 1),
         ENTRY(RS_XML_SubstituteEntitiesDefault, 1),
-        ENTRY(RS_XML_getNextSibling, 2),
+        ENTRY(RS_XML_getNextSibling, 3),
         ENTRY(R_getXMLNodeDocument, 1),
         ENTRY(RS_XML_createDocFromNode, 1),
         ENTRY(R_removeInternalNode, 2),
-	ENTRY(RS_XML_replaceXMLNode, 2),
-	ENTRY(RS_XML_xmlAddSiblingAt, 3),
+	ENTRY(RS_XML_replaceXMLNode, 3),
+	ENTRY(RS_XML_xmlAddSiblingAt, 4),
 	ENTRY(RS_XML_loadCatalog, 1),
 	ENTRY(RS_XML_clearCatalog, 0),
 	ENTRY(RS_XML_catalogAdd, 3),
@@ -197,7 +201,49 @@ static R_CallMethodDef callMethods[] = {
 	ENTRY(RS_XML_setKeepBlanksDefault, 1),
 	ENTRY(R_getDocEncoding, 1),
 	ENTRY(R_getLineNumber, 1),
-	ENTRY(R_addXMLNodeFinalizer, 1),
+        ENTRY(RS_XML_xpathEval, 7),
+        ENTRY(RS_XML_xmlNodeChildrenReferences, 3),
+	ENTRY(RS_XML_freeDoc, 1),
+	ENTRY(RS_XML_setRootNode, 2),
+	ENTRY(R_getNodeChildByIndex, 3),
+	ENTRY(RS_XML_setDocEl, 2),
+	ENTRY(RS_XML_isDescendantOf, 3),
+	ENTRY(RS_XML_getStructuredErrorHandler, 0),
+	ENTRY(RS_XML_setStructuredErrorHandler, 1),
+	ENTRY(R_convertDOMToHashTree, 4),
+	ENTRY(R_parseURI, 1),
+	ENTRY(R_getXMLFeatures, 0),
+	ENTRY(R_xmlReadMemory, 5), //XXX
+	ENTRY(R_xmlReadFile, 3), //XXX
+	ENTRY(RS_XML_internalNodeNamespaceDefinitions, 2),
+	ENTRY(R_libxmlTypeTable_names, 2),
+	ENTRY(R_libxmlTypeTable_lookup, 3),
+	ENTRY(RS_XML_xmlSchemaValidateDoc, 4),
+	ENTRY(R_XML_indexOfChild, 1),
+	ENTRY(RS_XML_xmlStopParser, 1),
+	ENTRY(R_clearNodeMemoryManagement, 1),
+	ENTRY(R_XMLInternalDocument_free, 1),
+	ENTRY(R_addXMLInternalDocument_finalizer, 2),
+	ENTRY(R_createXMLNode, 4),
+	ENTRY(RS_XML_xmlNodeName, 1),
+	ENTRY(RS_XML_xmlNodeNamespace, 1),
+	ENTRY(RS_XML_xmlNodeAttributes, 3),
+	ENTRY(RS_XML_xmlNodeChildrenReferences, 3),
+	ENTRY(R_xmlNodeValue, 3),
+	ENTRY(R_setXMLInternalTextNode_value, 2),
+	ENTRY(RS_XML_xmlNodeParent, 2),
+	ENTRY(R_getXMLNsRef, 1), // XXX
+	ENTRY(R_setXMLInternalTextNode_noenc, 1),
+	ENTRY(R_isNodeChildOfAt, 3),
+	ENTRY(R_findXIncludeStartNodes, 2),
+	ENTRY(RS_XML_removeAllNodeNamespaces, 1),
+	ENTRY(RS_XML_removeNodeNamespaces, 2),
+	ENTRY(R_matchNodesInList, 3),
+	ENTRY(RS_XML_copyNodesToDoc, 3),
+	ENTRY(RS_XML_getDocumentName, 1),
+	ENTRY(RS_XML_getDefaultValiditySetting, 1),
+	ENTRY(RS_XML_xmlXIncludeProcessFlags, 2),
+	ENTRY(RS_XML_xmlXIncludeProcessTreeFlags, 2),
 	{NULL, NULL, 0}
 };
 
